@@ -51,7 +51,7 @@ def generate(
 
 
 def _get_requests(client, parameters):
-    all_status = ['tiers_setup', 'inquiring', 'pending', 'approved', 'failed', 'draft']
+    all_status = ['tiers_setup', 'inquiring', 'pending', 'approved', 'failed']
 
     query = R()
     query &= R().created.ge(parameters['date']['after'])
@@ -70,7 +70,11 @@ def _get_requests(client, parameters):
     if parameters.get('hub') and parameters['hub']['all'] is False:
         query &= R().asset.connection.hub.id.oneof(parameters['hub']['choices'])
 
-    return client.requests.filter(query)
+    return client.requests.filter(query).select(
+        '-asset.items',
+        '-asset.params',
+        '-asset.configuration',
+    )
 
 
 def _process_line(request, connection):
