@@ -1,10 +1,6 @@
 #  Copyright © 2021 CloudBlue. All rights reserved.
-import os
 
 
-PROJECT_EXTENSION_BOILERPLATE_URL = 'https://github.com/cloudblue/connect-extension-python-boilerplate.git'
-PROJECT_EXTENSION_BOILERPLATE_TAG = os.environ.get('PROJECT_EXTENSION_BOILERPLATE_TAG')
-
 CAPABILITY_METHOD_MAP = {
     'asset_purchase_request_processing': 'process_asset_purchase_request',
     'asset_change_request_processing': 'process_asset_change_request',
@@ -85,3 +81,9 @@ CHUNK_FILE_STATUSES = [
 
 
 PYPI_EXTENSION_RUNNER_URL = 'https://pypi.org/pypi/connect-extension-runner/json'
+
+
+VALIDATION_RESULTS_HEADER = """
+| Field | Value |
+|:------|-------|
+"""
